@@ -79,12 +79,28 @@ make_embedded_interpreter(char const *progPath,
     return 0;
 }
 
+/* Perl caches $$ so the PID is wrong after we fork.  This
+   routine fixes it up */
+static void
+embperl_fix_pid(void)
+{
+    GV *tmpgv;
+    if ((tmpgv = gv_fetchpv("$",TRUE, SVt_PV))) {
+	SvREADONLY_off(GvSV(tmpgv));
+	sv_setiv(GvSV(tmpgv), PerlProc_getpid());
+	SvREADONLY_on(GvSV(tmpgv));
+    }
+}
+
 void
 run_embedded_filter(void)
 {
     char *args[] = { NULL };
 
+    embperl_fix_pid();
+
     perl_call_argv("do_main_loop", G_DISCARD | G_NOARGS, args);
 }
+
 #endif
 
