@@ -71,6 +71,11 @@ typedef int md_socklen_t;
 #include <sys/socket.h>
 #include <sys/un.h>
 
+/* Solaris does not define AF_LOCAL */
+#ifndef AF_LOCAL
+#define AF_LOCAL AF_UNIX
+#endif
+
 #ifdef ENABLE_DEBUGGING
 #include <signal.h>
 #define DEBUG(x) x
@@ -520,6 +525,9 @@ mfconnect(SMFICTX *ctx, char *hostname, _SOCK_ADDR *sa)
 #endif
         if (sa->sa_family == AF_INET) {
 	    tmp = inet_ntop(AF_INET, &insa->sin_addr, data->hostip, 65);
+	} else if (sa->sa_family == AF_LOCAL) {
+	    tmp = "127.0.0.1";
+	    strcpy(data->hostip, tmp);
 	} else {
 	    syslog(LOG_WARNING, "Unknown address family %d",
 		   (int) sa->sa_family);
